#
# spec file for package java-atk-wrapper
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global major_version 0.33
Name:           java-atk-wrapper
Version:        0.33.2
Release:        lp151.34.1
Summary:        Java ATK Wrapper
License:        LGPL-2.0+
Group:          Development/Libraries/Java
Url:            http://git.gnome.org/browse/java-atk-wrapper/
Source0:        http://ftp.gnome.org/pub/GNOME/sources/%{name}/%{major_version}/%{name}-%{version}.tar.xz
Source1:        HOWTO
Source2:        https://git.gnome.org/browse/java-atk-wrapper/plain/wrapper/manifest.txt
Source3:        https://git.gnome.org/browse/java-atk-wrapper/plain/autogen.sh
# Avoid libtool versioning; this library is dynamically loaded from Java code
Patch0:         jaw-avoid-version.patch
Patch1:         jaw-java_required.patch
Patch2:         jaw-quotes.patch
Patch3:         jaw-gdk.patch
Patch4:         jaw-javah.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  java-devel >= 1.7
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xprop
BuildRequires:  xz
BuildRequires:  pkgconfig(atk) >= 2.14.0
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(atspi-2) >= 2.14.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
Requires:       java >= 1.7
Requires:       xprop

%description
Java ATK Wrapper is a implementation of ATK by using JNI technic. It
converts Java Swing events into ATK events, and send these events to
ATK-Bridge.

JAW is part of the Bonobo deprecation project. It will replaces the
former java-access-bridge.
By talking to ATK-Bridge, it keeps itself from being affected by the
change of underlying communication mechanism.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
cp %{SOURCE1} .
cp %{SOURCE2} wrapper/
cp %{SOURCE3} .
rm -f wrapper/org/GNOME/Accessibility/AtkWrapper.java

%build
chmod +x autogen.sh
./autogen.sh
%configure JAVACFLAGS="-source 1.7 -target 1.7" --libdir=%{_libdir}/%{name}
make %{?_smp_mflags}

%install
make -C jni install DESTDIR=%{buildroot}
install wrapper/java-atk-wrapper.jar %{buildroot}%{_libdir}/%{name}/
find %{buildroot} -type f -name "*.la" -delete -print

%files
%doc AUTHORS
%doc COPYING.LESSER
%doc NEWS
%doc README
%doc HOWTO
%{_libdir}/%{name}/

%changelog
* Tue Jan  2 2018 fstrba@suse.com
- Added patch:
  * jaw-javah.patch
    + Do not search for javah, since it is not needed during the
    build
* Wed Nov  8 2017 fstrba@suse.com
- Added patch:
  * jaw-gdk.patch
    + Remove requirement of gdk3. It is not really needed.
* Thu Oct 26 2017 fstrba@suse.com
- Added patches:
  * jaw-quotes.patch
    + Add quotes when adding CFLAGS to JAW_CFLAGS in order to avoid
    that first of the CFLAGS be evaluated as a command
  * jaw-java_required.patch
    + Modify java requirement to 1.7, since the code cannot be
    built with source level 1.6 due to a diamond operator
- Modified patch:
  * jaw-avoid-version.patch
    + Completely discard all libtool versioning of the library
    + This library is not linked, only loaded by the java code and
    as such, it needs only .so extension
* Tue Oct 24 2017 fstrba@suse.com
- Remove the distributed AtkWrapper.java file before building,
  so that a correct version with the correct path to xprops can be
  generated during the build from AtkWrapper.java.in
* Tue Oct 10 2017 fstrba@suse.com
- Added patch:
  * jaw-avoid-version.patch
  - Avoid libtool generated symlinks for the native library,
    since it is loaded by System.loadLibrary which expects the
    library finish with .so anyway.
* Wed Sep  6 2017 fstrba@suse.com
- Upgrade to upsteam 0.33.2
- Removed patch:
  * java-atk-wrapper-fortify-decl.patch
    + Integrated upsteam
- Add manifest.txt missing from the tarball
- Force source/bytecode target to 1.7.
* Fri Oct 17 2014 fstrba@suse.com
- Upgrade to upstream 0.30.5
- Removed patch java-atk-wrapper-source-target.patch
  * No need to apply it since we can chose options for javac from
    configure line
- Force source/bytecode target to 1.5 at configure time
* Sat May  3 2014 fstrba@suse.com
- Added patch:
  * java-atk-wrapper-source-target-patch: pass options to javac to
    produce bytecode compatible with java 1.5 and higher.
- Allow to build on SLE11
  * xprop is in xorg-x11 package
* Thu Dec 12 2013 mvyskocil@suse.com
- Initial SUSE packaging of java-awt-wrapper
  * java-atk-wrapper-fortify-decl.patch to fix missing headers
